<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

if ( ! function_exists( 'swingpress_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Swingpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function swingpress_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'swingpress_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'swingpress_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Swingpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function swingpress_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'swingpress_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'swingpress_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Swingpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function swingpress_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'swingpress_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'swingpress_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Swingpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function swingpress_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

function swingpress_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

function swingpress_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function swingpress_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

function swingpress_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[slider_content_type]' )->value();
	return swingpress_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[gallery_content_type]' )->value();
	return swingpress_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[gallery_content_type]' )->value();
	return swingpress_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[gallery_content_type]' )->value();
	return swingpress_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is trip.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is trip types.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured section content type is destination.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'destination' == $content_type );
}

function swingpress_pro_is_featured_section_content_product_cat_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'product_cat' == $content_type );
}


/**
 * Check if featured section content type is activity.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_content_type]' )->value();
	return swingpress_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if about section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[about_content_type]' )->value();
	return swingpress_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[about_content_type]' )->value();
	return swingpress_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[about_content_type]' )->value();
	return swingpress_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section wp travel is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_about_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[about_content_type]' )->value();
	return swingpress_pro_is_about_section_enable( $control ) && class_exists( 'WP_Travel' );
}


/**
 * Check if popular destination section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_destination_content_type]' )->value();
	return swingpress_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if package section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[package_content_type]' )->value();
	return swingpress_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[package_content_type]' )->value();
	return swingpress_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[package_content_type]' )->value();
	return swingpress_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[package_content_type]' )->value();
	return swingpress_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}



/**
 * Check if featured_post section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_post_content_type]' )->value();
	return swingpress_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post section content type is trip types.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_post_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_post_content_type]' )->value();
	return swingpress_pro_is_featured_post_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured_post section content type is destination.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_post_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_post_content_type]' )->value();
	return swingpress_pro_is_featured_post_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured_post section content type is activity.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_featured_post_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_post_content_type]' )->value();
	return swingpress_pro_is_featured_post_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if service section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[service_section_enable]' )->value() );
}


function swingpress_pro_is_service_section_icon_enable( $control ) {
	$icon = $control->manager->get_setting( 'swingpress_pro_theme_options[service_section_icon_enable]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( true == $icon );
}
/**
 * Check if service section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

function swingpress_pro_is_service_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'trip' == $content_type );
}

function swingpress_pro_is_service_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function swingpress_pro_is_service_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'activity' == $content_type );
}

function swingpress_pro_is_service_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[service_content_type]' )->value();
	return swingpress_pro_is_service_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

function swingpress_pro_is_blog_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'trip' == $content_type );
}

function swingpress_pro_is_blog_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function swingpress_pro_is_blog_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'activity' == $content_type );
}

function swingpress_pro_is_blog_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[blog_content_type]' )->value();
	return swingpress_pro_is_blog_section_enable( $control ) && ( 'destination' == $content_type );
}



/**
 * Check if inner_wrapper section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_inner_wrapper_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_section_enable]' )->value() );
}

/**
 * Check if inner_wrapper section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_inner_wrapper_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if inner_wrapper section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_inner_wrapper_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if inner_wrapper section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_inner_wrapper_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if inner_wrapper section content type is recent.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_inner_wrapper_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'recent' == $content_type );
}

function swingpress_pro_is_inner_wrapper_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'trip' == $content_type );
}

function swingpress_pro_is_inner_wrapper_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function swingpress_pro_is_inner_wrapper_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'activity' == $content_type );
}

function swingpress_pro_is_inner_wrapper_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]' )->value();
	return swingpress_pro_is_inner_wrapper_section_enable( $control ) && ( 'destination' == $content_type );
}


/**
 * Check if testimonial section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_content_type]' )->value();
	return swingpress_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_content_type]' )->value();
	return swingpress_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_content_type]' )->value();
	return swingpress_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_content_type]' )->value();
	return swingpress_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is author.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_testimonial_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[testimonial_content_type]' )->value();
	return swingpress_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if video section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_heading_tags_enable( $control ) {

	$tags = $control->manager->get_setting( 'swingpress_pro_theme_options[heading_tags]' )->value();
	return ($control->id == 'swingpress_pro_theme_options['.$tags.']');

}

//recent product 

function swingpress_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_section_enable]' )->value() );
}

function swingpress_pro_is_recent_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_content_type]' )->value();
	return swingpress_pro_is_recent_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_product section content type is product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_content_type]' )->value();
	return swingpress_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product_cat.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_content_type]' )->value();
	return swingpress_pro_is_recent_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if popular_product section content type is recent_product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_content_type]' )->value();
	return swingpress_pro_is_recent_product_section_enable( $control ) && ( 'recent_product' == $content_type );
}


/*recent section*/

function swingpress_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[recent_section_enable]' )->value() );
}

function swingpress_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_content_type]' )->value();
	return swingpress_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_content_type]' )->value();
	return swingpress_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_content_type]' )->value();
	return swingpress_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is recent.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_recent_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_content_type]' )->value();
	return swingpress_pro_is_recent_section_enable( $control ) && ( 'recent' == $content_type );
}

/*end recent section*/

/*magazine latest post section*/

function swingpress_pro_is_magazine_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_latest_post_section_enable]' )->value() );
}

function swingpress_pro_is_magazine_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return swingpress_pro_is_magazine_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return swingpress_pro_is_magazine_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return swingpress_pro_is_magazine_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is magazine_latest_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_latest_post_section_content_magazine_latest_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return swingpress_pro_is_magazine_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}


/*magazine most_viewed post section*/

function swingpress_pro_is_magazine_most_viewed_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_section_enable]' )->value() );
}

function swingpress_pro_is_magazine_most_viewed_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]' )->value();
	return swingpress_pro_is_magazine_most_viewed_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_most_viewed_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_most_viewed_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]' )->value();
	return swingpress_pro_is_magazine_most_viewed_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_most_viewed_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_most_viewed_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]' )->value();
	return swingpress_pro_is_magazine_most_viewed_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_most_viewed_post section content type is magazine_most_viewed_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_most_viewed_post_section_content_magazine_most_viewed_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]' )->value();
	return swingpress_pro_is_magazine_most_viewed_post_section_enable( $control ) && ( 'recent' == $content_type );
}

/*magazine recent post section*/

function swingpress_pro_is_magazine_recent_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_recent_post_section_enable]' )->value() );
}

function swingpress_pro_is_magazine_recent_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return swingpress_pro_is_magazine_recent_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_recent_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return swingpress_pro_is_magazine_recent_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_recent_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return swingpress_pro_is_magazine_recent_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is magazine_recent_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_recent_post_section_content_magazine_recent_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return swingpress_pro_is_magazine_recent_post_section_enable( $control ) && ( 'recent' == $content_type );
}

/*magazine latest post section*/

function swingpress_pro_is_magazine_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_popular_post_section_enable]' )->value() );
}

function swingpress_pro_is_magazine_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return swingpress_pro_is_magazine_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return swingpress_pro_is_magazine_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return swingpress_pro_is_magazine_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is magazine_popular_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_popular_post_section_content_magazine_popular_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return swingpress_pro_is_magazine_popular_post_section_enable( $control ) && ( 'recent' == $content_type );
}

/*latest post section*/

function swingpress_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[latest_post_section_enable]' )->value() );
}

function swingpress_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_post_content_type]' )->value();
	return swingpress_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_post_content_type]' )->value();
	return swingpress_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_post_content_type]' )->value();
	return swingpress_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_post section content type is latest_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_latest_post_section_content_latest_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_post_content_type]' )->value();
	return swingpress_pro_is_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}



/*magazine featured post section*/

function swingpress_pro_is_magazine_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_featured_post_section_enable]' )->value() );
}

function swingpress_pro_is_magazine_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return swingpress_pro_is_magazine_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return swingpress_pro_is_magazine_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return swingpress_pro_is_magazine_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is magazine_featured_post.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_magazine_featured_post_section_content_magazine_featured_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return swingpress_pro_is_magazine_featured_post_section_enable( $control ) && ( 'recent' == $content_type );
}



/*breaking news section*/

function swingpress_pro_is_breaking_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[breaking_news_section_enable]' )->value() );
}

function swingpress_pro_is_breaking_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[breaking_news_content_type]' )->value();
	return swingpress_pro_is_breaking_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if breaking_news section content type is page.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_breaking_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[breaking_news_content_type]' )->value();
	return swingpress_pro_is_breaking_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if breaking_news section content type is category.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_breaking_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[breaking_news_content_type]' )->value();
	return swingpress_pro_is_breaking_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if breaking_news section content type is breaking_news.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_breaking_news_section_content_breaking_news_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[breaking_news_content_type]' )->value();
	return swingpress_pro_is_breaking_news_section_enable( $control ) && ( 'recent' == $content_type );
}

/*Popular Product section*/

function swingpress_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[popular_product_section_enable]' )->value() );
}

function swingpress_pro_is_popular_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_product_content_type]' )->value();
	return swingpress_pro_is_popular_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_product section content type is product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_product_content_type]' )->value();
	return swingpress_pro_is_popular_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product_cat.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[popular_product_content_type]' )->value();
	return swingpress_pro_is_popular_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if popular_product section content type is recent_product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_popular_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[recent_product_content_type]' )->value();
	return swingpress_pro_is_popular_product_section_enable( $control ) && ( 'recent_product' == $content_type );
}

/*Popular Product section*/

function swingpress_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[latest_product_section_enable]' )->value() );
}

/**
 * Check if popular_product section content type is product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_latest_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_product_content_type]' )->value();
	return swingpress_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product_cat.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function swingpress_pro_is_latest_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[latest_product_content_type]' )->value();
	return swingpress_pro_is_latest_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}


/*featured product*/

function swingpress_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_section_enable]' )->value() );
}



function swingpress_pro_is_featured_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_content_type]' )->value();
	return swingpress_pro_is_featured_product_section_enable( $control ) && ( 'category' == $content_type );
}

function swingpress_pro_is_featured_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_content_type]' )->value();
	return swingpress_pro_is_featured_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function swingpress_pro_is_featured_product_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_content_type]' )->value();
	return swingpress_pro_is_featured_product_section_enable( $control ) && ( 'destination' == $content_type );
}

function swingpress_pro_is_featured_product_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_content_type]' )->value();
	return swingpress_pro_is_featured_product_section_enable( $control ) && ( 'activity' == $content_type );
}

function swingpress_pro_is_featured_product_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'swingpress_pro_theme_options[featured_product_content_type]' )->value();
	return swingpress_pro_is_featured_product_section_enable( $control ) && ( 'trip-types' == $content_type );
}


/*magazine ads section*/

function swingpress_pro_is_advertisement_section_enable( $control ) {
	return ( $control->manager->get_setting( 'swingpress_pro_theme_options[advertisement_section_enable]' )->value() );
}


//pro layout 
function swingpress_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'swingpress_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

//second layout 
function swingpress_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'swingpress_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

//third layout 
function swingpress_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'swingpress_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

//fourth layout 
function swingpress_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'swingpress_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}

