<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 * @return array An array of default values
 */

function swingpress_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$swingpress_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#00afe9',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,
		'search_nav_enable'				=> true,
		'cart_nav_enable'				=> false,


		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'swingpress-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'swingpress-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'swingpress-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		'all_sortable'					=> 'slider,trip_search,service,featured,about,package,popular_destination,testimonial,blog,gallery,subscription,featured_post,inner_wrapper,recent,featured_product,recent_product,latest_product,latest_post,breaking_news,magazine_featured_post,magazine_popular_post,magazine_recent_post,magazine_latest_post,magazine_most_viewed_post',
    

		// homepage sections sortable
		'default_sortable' 				=> 'slider,trip_search,service,featured,about,package,popular_destination,testimonial,blog,gallery,subscription',

		'second_sortable'				=> 'slider,featured_product,recent_product,about,latest_product,featured,subscription,testimonial,latest_post',

		'third_sortable'				=> 'slider,featured_post,inner_wrapper,blog,recent,subscription',

		'fourth_sortable'				=> 'breaking_news,magazine_featured_post,magazine_wrapper,magazine_latest_post,magazine_most_viewed_post',



		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'swingpress-pro' ),
		'hide_btn' 						=> false,
		'hide_category'					=> false,
		'hide_content'					=> false,
		'hide_image'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_content_type'			=> 'category',
		'slider_design'					=> "first-design",
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Discover More', 'swingpress-pro' ),
		'slider_video_label'			=> esc_html__( 'Watch the video', 'swingpress-pro' ),


		// trip search
		'trip_search_section_enable'	=> true,
		'trip_search_placeholder_1'		=> esc_html__( 'Ex: Trekking', 'swingpress-pro' ),
		'trip_search_placeholder_2'		=> esc_html__( 'Trip Type', 'swingpress-pro' ),
		'trip_search_placeholder_3'		=> esc_html__( 'Destination', 'swingpress-pro' ),

		// featured
		'featured_sub_title'				=> esc_html__( 'Featured activities', 'swingpress-pro' ),
		'featured_title'				=> esc_html__( 'Travel anywhere', 'swingpress-pro' ),
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_auto_slide_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_count'				=> 4,
		'popular_destination_title'				=> esc_html__( 'Popular Trips', 'swingpress-pro' ),
		'popular_destination_sub_title'			=> esc_html__( 'More than 25+ tour types for you', 'swingpress-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Go places you&#39;ve dreamed of', 'swingpress-pro' ),
		'about_sub_title'				=> esc_html__( 'About Us', 'swingpress-pro' ),
		'about_description'				=> esc_html__( 'Between the many mouths to feed, entry to myriad attractions and school holiday price hikes, traveling with kids can quickly add up. Follow these top tips to make your hard-earned cash go further as you and your brood explore the world...', 'swingpress-pro' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'swingpress-pro' ),

		
		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_title'					=> esc_html__( 'Recommended Packages', 'swingpress-pro' ),
		'package_sub_title'				=> esc_html__( 'More than 2000+ travel destinations', 'swingpress-pro' ),

		// featured_post
		'featured_post_section_enable'		=> true,
		'featured_post_content_type'		=> 'category',
		'featured_post_count'				=> 3,

		// service
		'service_section_enable'		=> true,
		'service_section_icon_enable'	=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_title'					=> esc_html__( 'How we help you', 'swingpress-pro' ),
		'service_sub_title'				=> esc_html__( 'Let’s go on an adventure', 'swingpress-pro' ),


		// gallery
		'gallery_section_enable'	=> true,
		'gallery_content_type'		=> 'post',
		'gallery_count'				=> 11,
		'gallery_title'				=> esc_html__( 'Travel to make memories all around the world', 'swingpress-pro' ),
		'gallery_short_description'	=> esc_html__( 'When on the road, this isn’t always possible, with time, space and convenience restrictions often conspiring against your ideal lifestyle & so on other things. Planes are fastest methods of getting around the world but it is a bit expensive.When on the road, this isn’t always possible, with time, space and convenience restrictions often conspiring against your ideal lifestyle & so on other things.', 'swingpress-pro' ),
		'gallery_btn_title'			=> esc_html__( 'View All Gallery', 'swingpress-pro' ),
		
	
		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,
		'blog_title'					=> esc_html__( 'Our recent articles', 'swingpress-pro' ),
		'blog_sub_title'				=> esc_html__( 'Know what’s happening', 'swingpress-pro' ),
		'blog_btn_title'				=> esc_html__( 'Read More', 'swingpress-pro' ),
		'blog_alt_btn_title'			=> esc_html__( 'Show All Aricle', 'swingpress-pro' ),

		// inner_wrapper
		'inner_wrapper_section_enable'			=> true,
		'inner_wrapper_content_type'			=> 'category',
		'inner_wrapper_count'					=> 4,
		'inner_wrapper_title'					=> esc_html__( 'Popular Posts', 'swingpress-pro' ),
		'inner_wrapper_sub_title'				=> esc_html__( 'Let’s go on an adventure', 'swingpress-pro' ),
		'inner_wrapper_btn_title'				=> esc_html__( 'Read More', 'swingpress-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_section_title'		=> esc_html__( 'What Our Clients Says', 'swingpress-pro' ),

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Keep in touch', 'swingpress-pro' ),
		'subscription_title'			=> esc_html__( 'Travel with us!', 'swingpress-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'swingpress-pro' ),

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'category',
		'popular_count'						=> 3,

		// recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'Recent Posts', 'swingpress-pro' ),
		'recent_sub_title'					=> esc_html__( 'Let’s go on an adventure', 'swingpress-pro' ),
		'recent_btn_title'					=> esc_html__( 'Read More', 'swingpress-pro' ),
		'recent_content_type'			=> 'category',
		'recent_count'					=> 3,


		// latest_post
		'latest_post_section_enable'		=> true,
		'latest_post_title'					=> esc_html__( 'Latest posts', 'swingpress-pro' ),
		'latest_post_sub_title'				=> esc_html__( 'Let’s go on an adventure', 'swingpress-pro' ),
		'latest_post_btn_title'				=> esc_html__( 'Read More', 'swingpress-pro' ),
		'latest_post_content_type'			=> 'category',
		'latest_post_count'					=> 3,

		// magazine_latest_post
		'magazine_latest_post_section_enable'		=> true,
		'magazine_latest_post_title'				=> esc_html__( 'Latest posts', 'swingpress-pro' ),
		'magazine_latest_post_content_type'			=> 'category',
		'magazine_latest_post_count'				=> 3,


		// magazine_recent_post
		'magazine_recent_post_section_enable'		=> true,
		'magazine_recent_post_title'				=> esc_html__( 'Recent posts', 'swingpress-pro' ),
		'magazine_recent_post_content_type'			=> 'category',
		'magazine_recent_post_count'				=> 3,

		// magazine_popular_post
		'magazine_popular_post_section_enable'		=> true,
		'magazine_popular_post_title'				=> esc_html__( 'Popular Posts', 'swingpress-pro' ),
		'magazine_popular_post_content_type'		=> 'category',
		'magazine_popular_post_count'				=> 3,


		// magazine_most_viewed_post
		'magazine_most_viewed_post_section_enable'		=> true,
		'magazine_most_viewed_post_title'				=> esc_html__( 'most viewed posts', 'swingpress-pro' ),
		'magazine_most_viewed_post_content_type'		=> 'category',
		'magazine_most_viewed_post_count'				=> 3,

		// breaking_news
		'breaking_news_section_enable'		=> true,
		'breaking_news_label'				=> esc_html__( 'Trending News', 'swingpress-pro' ),
		'breaking_news_content_type'		=> 'category',
		'breaking_news_count'				=> 3,

		// magazine_featured_post
		'magazine_featured_post_section_enable'		=> true,
		'magazine_featured_post_content_type'		=> 'category',
		'magazine_featured_post_count'				=> 3,


		// latest Product
		'latest_product_section_enable'		=> true,
		'latest_product_title'				=> esc_html__( 'NEW ARRIVALS', 'swingpress-pro' ),
		'latest_product_sub_title'		=> esc_html__( 'All Styles in This Spring', 'swingpress-pro' ),
		'latest_product_count'				=> 4,
		'latest_product_content_type'		=> 'product',

		// recent Product
		'recent_product_section_enable'		=> true,
		'recent_product_title'				=> esc_html__( 'NEW ARRIVALS', 'swingpress-pro' ),
		'recent_product_sub_title'		=> esc_html__( 'All Styles in This Spring', 'swingpress-pro' ),
		'recent_product_count'				=> 4,
		'recent_product_content_type'		=> 'product',

		// Featured Product
		'featured_product_section_enable'		=> true,
		'featured_product_count'				=> 2,
		'featured_product_content_type'		=> 'category',

		'advertisement_section_enable'		=> true,
	);

	$output = apply_filters( 'swingpress_pro_default_theme_options', $swingpress_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}