<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'swingpress_pro_about_section', array(
	'title'             => esc_html__( 'About Us','swingpress-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
            ||
            swingpress_pro_is_second_layout( $control )
        );
    },
) );

// About content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_about_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'swingpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'swingpress-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'swingpress-pro' ),
	),
) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[about_video_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_video_url]', array(
	'label'           	=> esc_html__( 'Video Link', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_about_section',
	'active_callback' 	=> 'swingpress_pro_is_about_section_enable',
	'type'				=> 'url',
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_page',
) );

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_about_section',
	'choices'			=> swingpress_pro_page_choices(),
	'active_callback'	=> 'swingpress_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_page',
) );

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_about_section',
	'choices'			=> swingpress_pro_post_choices(),
	'active_callback'	=> 'swingpress_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_about_section',
	'active_callback' 	=> 'swingpress_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .wrapper .entry-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_about_section',
	'active_callback' 	=> 'swingpress_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .wrapper .section-content p',
		'settings'            => 'swingpress_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_about_section',
	'active_callback' 	=> 'swingpress_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-section .read-more a',
		'settings'            => 'swingpress_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_about_section',
	'active_callback' 	=> 'swingpress_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about image setting and control.
$wp_customize->add_setting( 'swingpress_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'swingpress_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'swingpress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'swingpress-pro' ), 650, 700 ),
		'section'     		=> 'swingpress_pro_about_section',
		'active_callback'	=> 'swingpress_pro_is_about_section_content_custom_enable',
) ) );

for ( $i = 1; $i <= 4; $i++ ) :
	$wp_customize->add_setting( 'swingpress_pro_theme_options[about_counter_count_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[about_counter_count_'.$i.']', array(
		'label'           	=> esc_html__( 'Counter Count ', 'swingpress-pro' ).$i,
		'section'        	=> 'swingpress_pro_about_section',
		'active_callback' 	=> 'swingpress_pro_is_about_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'swingpress_pro_theme_options[about_counter_label_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[about_counter_label_'.$i.']', array(
		'label'           	=> esc_html__( 'Counter Label ', 'swingpress-pro' ).$i,
		'section'        	=> 'swingpress_pro_about_section',
		'active_callback' 	=> 'swingpress_pro_is_about_section_enable',
		'type'				=> 'text',
	) );



endfor;