<?php
/**
 * Featured post_Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Featured post_section
$wp_customize->add_section( 'swingpress_pro_featured_product_section', array(
    'title'             => esc_html__( 'Featured Product','swingpress-pro' ),
    'description'       => esc_html__( 'Featured Product Section options.', 'swingpress-pro' ),
    'panel'             => 'swingpress_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_second_layout( $control )
        );
    },
) );

// Featured post_content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_product_section_enable]', array(
    'default'           =>  $options['featured_product_section_enable'],
    'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[featured_product_section_enable]', array(
    'label'             => esc_html__( 'Featured Product Section Enable', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_featured_product_section',
    'on_off_label'      => swingpress_pro_switch_options(),
) ) );



// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_product_count]', array(
    'default'           => $options['featured_product_count'],
    'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
    'validate_callback' => 'swingpress_pro_validate_featured_product_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_product_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
    'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_featured_product_section',
    'active_callback'   => 'swingpress_pro_is_featured_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 4,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

// Featured post_content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_product_content_type]', array(
    'default'           => $options['featured_product_content_type'],
    'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_product_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_featured_product_section',
    'type'              => 'select',
    'active_callback'   => 'swingpress_pro_is_featured_product_section_enable',
    'choices'           => swingpress_pro_featured_content_type(),
) );

for ( $i=1; $i <= $options['featured_product_count']; $i++ ) { 
    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'swingpress_pro_theme_options[featured_product_content_category_' . $i . ']', array(
        'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_product_content_category_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Category %d', 'swingpress-pro'), $i ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
        'section'           => 'swingpress_pro_featured_product_section',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_product_section_content_category_enable'
    ) ) );

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'swingpress_pro_theme_options[featured_product_content_trip_types_' . $i . ']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_product_content_trip_types_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Trip Types %d', 'swingpress-pro'), $i ),
        'section'           => 'swingpress_pro_featured_product_section',
        'taxonomy'          => 'itinerary_types',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_product_section_content_trip_types_enable'
    ) ) );

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'swingpress_pro_theme_options[featured_product_content_activity_' . $i . ']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_product_content_activity_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Activities %d', 'swingpress-pro'), $i ),
        'section'           => 'swingpress_pro_featured_product_section',
        'taxonomy'          => 'activity',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_product_section_content_activity_enable'
    ) ) );

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'swingpress_pro_theme_options[featured_product_content_destination_' . $i . ']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_product_content_destination_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Destinations %d ', 'swingpress-pro'), $i ),
        'section'           => 'swingpress_pro_featured_product_section',
        'taxonomy'          => 'travel_locations',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_product_section_content_destination_enable'
    ) ) );

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'swingpress_pro_theme_options[featured_product_content_product_category_' . $i . ']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_product_content_product_category_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product Category %d ', 'swingpress-pro'), $i ),
        'section'           => 'swingpress_pro_featured_product_section',
        'taxonomy'          => 'product_cat',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_product_section_content_product_category_enable'
    ) ) );


    // Featured post_image enable control and setting
    $wp_customize->add_setting( 'swingpress_pro_theme_options[featured_product_background_image_' . $i . ']', array(
        'sanitize_callback' => 'swingpress_pro_sanitize_image',
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'swingpress_pro_theme_options[featured_product_background_image_' . $i . ']',
            array(
            'label'             => sprintf( esc_html__( 'Category Image %d', 'swingpress-pro' ), $i ),
            'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'swingpress-pro' ), 500, 500 ),
            'section'           => 'swingpress_pro_featured_product_section',
            'active_callback'   => 'swingpress_pro_is_featured_product_section_content_category_enable',
    ) ) );

    // counter hr setting and control
    $wp_customize->add_setting( 'swingpress_pro_theme_options[featured_product_hr_'. $i .']', array(
        'sanitize_callback' => 'swingpress_pro_sanitize_html',
    ) );
}



