<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'swingpress_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','swingpress-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
            ||
            swingpress_pro_is_second_layout( $control )
        );
    },
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_featured_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );


// popular destination read more setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_title]', array(
	'default'			=> $options['featured_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_featured_section',
	'active_callback' 	=> 'swingpress_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[featured_title]', array(
		'selector'            => '#featured .section-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_featured_title_partial',
    ) );
}


$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_sub_title]', array(
	'default'			=> $options['featured_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_featured_section',
	'active_callback' 	=> 'swingpress_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[featured_sub_title]', array(
		'selector'            => '#featured .section-header p',
		'settings'            => 'swingpress_pro_theme_options[featured_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_featured_sub_title_partial',
    ) );
}




// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_featured_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_featured_section',
	'active_callback'   => 'swingpress_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_featured_section_enable',
	'choices'			=> swingpress_pro_featured_content_type(),
) );

for ( $i=1; $i <= $options['featured_count']; $i++ ) { 
	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'swingpress_pro_theme_options[featured_content_category_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_content_category_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'swingpress-pro'), $i ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
		'section'           => 'swingpress_pro_featured_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'swingpress_pro_is_featured_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'swingpress_pro_theme_options[featured_content_trip_types_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_content_trip_types_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Trip Types %d', 'swingpress-pro'), $i ),
		'section'           => 'swingpress_pro_featured_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'swingpress_pro_is_featured_section_content_trip_types_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'swingpress_pro_theme_options[featured_content_activity_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_content_activity_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Activities %d', 'swingpress-pro'), $i ),
		'section'           => 'swingpress_pro_featured_section',
		'taxonomy'			=> 'activity',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'swingpress_pro_is_featured_section_content_activity_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'swingpress_pro_theme_options[featured_content_destination_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_content_destination_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Destinations %d ', 'swingpress-pro'), $i ),
		'section'           => 'swingpress_pro_featured_section',
		'taxonomy'			=> 'travel_locations',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'swingpress_pro_is_featured_section_content_destination_enable'
	) ) );

	$wp_customize->add_setting(  'swingpress_pro_theme_options[featured_content_product_category_' . $i . ']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[featured_content_product_category_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product Category %d ', 'swingpress-pro'), $i ),
        'section'           => 'swingpress_pro_featured_section',
        'taxonomy'          => 'product_cat',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'swingpress_pro_is_featured_section_content_product_cat_enable'
    ) ) );

	// Featured image enable control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_background_image_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'swingpress_pro_theme_options[featured_background_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Category Image %d', 'swingpress-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'swingpress-pro' ), 500, 500 ),
			'section'     		=> 'swingpress_pro_featured_section',
			'active_callback'	=> 'swingpress_pro_is_featured_section_content_category_enable',
	) ) );

	// counter hr setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[featured_hr_'. $i .']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_html',
	) );
}


