<?php
/**
 * gallery Section options
 *
 * @package Theme Palace
 * @subpackage swingpress Pro
 * @since swingpress Pro 1.0.0
 */

// Add gallery section
$wp_customize->add_section( 'swingpress_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','swingpress-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
        );
    },
) );

// gallery content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_gallery_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#gallery .tooltiptext',
		'settings'            => 'swingpress_pro_theme_options[gallery_section_enable]',
    ) );
}


// Title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => $options['gallery_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_title]', array(
	'label'             => sprintf( esc_html__( 'Title', 'swingpress-pro' ) ),
	'section'        	=> 'swingpress_pro_gallery_section',
	'active_callback' 	=> 'swingpress_pro_is_gallery_section_enable',
	'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[gallery_title]', array(
		'selector'            => '#gallery h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_gallery_title_partial',
    ) );
}

$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => $options['gallery_btn_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_btn_title]', array(
	'label'             => sprintf( esc_html__( 'Btn Title', 'swingpress-pro' ) ),
	'section'        	=> 'swingpress_pro_gallery_section',
	'active_callback' 	=> 'swingpress_pro_is_gallery_section_enable',
	'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[gallery_btn_title]', array(
		'selector'            => '#gallery .read-more a',
		'settings'            => 'swingpress_pro_theme_options[gallery_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_gallery_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_btn_url]', array(
	'label'             => sprintf( esc_html__( 'Btn Url', 'swingpress-pro' ) ),
	'section'        	=> 'swingpress_pro_gallery_section',
	'active_callback' 	=> 'swingpress_pro_is_gallery_section_enable',
	'type'				=> 'url',
	) );

// Short Description setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_short_description]', array(
		'sanitize_callback' => 'wp_kses_post',
		'default' => $options['gallery_short_description'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_short_description]', array(
		'label'             => sprintf( esc_html__( 'Short Description', 'swingpress-pro' ) ),
		'section'        	=> 'swingpress_pro_gallery_section',
		'active_callback' 	=> 'swingpress_pro_is_gallery_section_enable',
		'type'				=> 'textarea',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[gallery_short_description]', array(
		'selector'            => '#gallery div.section-content p',
		'settings'            => 'swingpress_pro_theme_options[gallery_short_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_gallery_short_description_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 100. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_gallery_section',
	'active_callback'   => 'swingpress_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 100,
		'style' => 'width: 100px;'
		),
) );

// gallery content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_gallery_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_gallery_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_gallery_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_gallery_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_gallery_section_content_post_enable',
	) ) );

endfor;