<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'swingpress_pro_inner_wrapper_section', array(
	'title'             => esc_html__( 'Inner Wrapper','swingpress-pro' ),
	'description'       => esc_html__( 'Inner Wrapper Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_third_layout( $control )
        );
    },
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_section_enable]', array(
	'default'			=> 	$options['inner_wrapper_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[inner_wrapper_section_enable]', array(
	'label'             => esc_html__( 'Inner Wrapper Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['inner_wrapper_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[inner_wrapper_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_inner_wrapper_section',
	'active_callback' 	=> 'swingpress_pro_is_inner_wrapper_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[inner_wrapper_title]', array(
		'selector'            => '.home #inner-content-wrapper .section-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[inner_wrapper_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_inner_wrapper_title_partial',
    ) );
}

// blog title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['inner_wrapper_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[inner_wrapper_sub_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_inner_wrapper_section',
	'active_callback' 	=> 'swingpress_pro_is_inner_wrapper_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[inner_wrapper_sub_title]', array(
		'selector'            => '.home #inner-content-wrapper .section-header p',
		'settings'            => 'swingpress_pro_theme_options[inner_wrapper_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_inner_wrapper_sub_title_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['inner_wrapper_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[inner_wrapper_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_inner_wrapper_section',
	'active_callback' 	=> 'swingpress_pro_is_inner_wrapper_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[inner_wrapper_btn_title]', array(
		'selector'            => '.home #inner-content-wrapper .read-more a',
		'settings'            => 'swingpress_pro_theme_options[inner_wrapper_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_inner_wrapper_btn_title_partial',
    ) );
}

// Blog content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_content_type]', array(
	'default'          	=> $options['inner_wrapper_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[inner_wrapper_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_inner_wrapper_section_enable',
	'choices'			=> swingpress_pro_blog_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_count]', array(
	'default'          	=> $options['inner_wrapper_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_inner_wrapper_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[inner_wrapper_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'active_callback'   => 'swingpress_pro_is_inner_wrapper_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['inner_wrapper_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[inner_wrapper_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_inner_wrapper_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[inner_wrapper_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_inner_wrapper_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[inner_wrapper_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_inner_wrapper_section',
		'choices'			=> swingpress_pro_trip_choices(),
		'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_trip_enable',
	) ) );


endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[inner_wrapper_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[inner_wrapper_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'swingpress_pro_theme_options[inner_wrapper_category_exclude]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[inner_wrapper_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_recent_enable'
) ) );

$wp_customize->add_setting(  'swingpress_pro_theme_options[inner_wrapper_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[inner_wrapper_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[inner_wrapper_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[inner_wrapper_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[inner_wrapper_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[inner_wrapper_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_inner_wrapper_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_inner_wrapper_section_content_destination_enable'
) ) );