<?php
/**
 * magazine_most_viewed_post Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add magazine_most_viewed_post section
$wp_customize->add_section( 'swingpress_pro_magazine_most_viewed_post_section', array(
	'title'             => esc_html__( 'Magazine Most Viewed Posts','swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_fourth_layout( $control )
        );
    },
) );	

// magazine_most_viewed_post content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_section_enable]', array(
	'default'			=> 	$options['magazine_most_viewed_post_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[magazine_most_viewed_post_section_enable]', array(
	'label'             => esc_html__( 'Magazine Most Viewed Posts Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// magazine_most_viewed_post title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['magazine_most_viewed_post_title'],
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[magazine_most_viewed_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_magazine_most_viewed_post_section',
	'active_callback' 	=> 'swingpress_pro_is_magazine_most_viewed_post_section_enable',
	'type'				=> 'text',
) );

// magazine_most_viewed_post content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]', array(
	'default'          	=> $options['magazine_most_viewed_post_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_magazine_most_viewed_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'swingpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'swingpress-pro' ),
		'category' 	=> esc_html__( 'Category', 'swingpress-pro' ),
		'recent' 	=> esc_html__( 'recent', 'swingpress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_count]', array(
	'default'          	=> $options['magazine_most_viewed_post_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_magazine_most_viewed_post_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[magazine_most_viewed_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
	'active_callback'   => 'swingpress_pro_is_magazine_most_viewed_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['magazine_most_viewed_post_count']; $i++ ) :
	// magazine_most_viewed_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[magazine_most_viewed_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_magazine_most_viewed_post_section_content_page_enable',
	) ) );

	// magazine_most_viewed_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[magazine_most_viewed_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_magazine_most_viewed_post_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[magazine_most_viewed_post_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[magazine_most_viewed_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_magazine_most_viewed_post_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'swingpress_pro_theme_options[magazine_most_viewed_post_category_exclude]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[magazine_most_viewed_post_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_magazine_most_viewed_post_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_magazine_most_viewed_post_section_content_magazine_most_viewed_post_enable'
) ) );

