<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'swingpress_pro_package_section', array(
	'title'             => esc_html__( 'Package','swingpress-pro' ),
	'description'       => esc_html__( 'Package Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
        );
    },
) );

// Package content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_package_section',
	'active_callback' 	=> 'swingpress_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[package_title]', array(
		'selector'            => '#explore .section-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_package_title_partial',
    ) );
}

$wp_customize->add_setting( 'swingpress_pro_theme_options[package_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_package_section',
	'active_callback' 	=> 'swingpress_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[package_sub_title]', array(
		'selector'            => '#explore .section-header p',
		'settings'            => 'swingpress_pro_theme_options[package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_package_sub_title_partial',
    ) );
}


// Package content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_package_section_enable',
	'choices'			=> swingpress_pro_package_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[package_content_trip_types]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Multiple Trip Types', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[package_content_activity]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[package_content_activity]', array(
	'label'             => esc_html__( 'Select Multiple Activities', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[package_content_destination]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[package_content_destination]', array(
	'label'             => esc_html__( 'Select Multiple Destination', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_package_section_content_destination_enable'
) ) );
