<?php
/**
 * Popular Destination Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Popular Destination section
$wp_customize->add_section( 'swingpress_pro_popular_destination_section', array(
	'title'             => esc_html__( 'Popular Destination','swingpress-pro' ),
	'description'       => esc_html__( 'Popular Destination Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
        );
    },
) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_section_enable]', array(
	'default'			=> 	$options['popular_destination_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[popular_destination_section_enable]', array(
	'label'             => esc_html__( 'Popular Destination Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_auto_slide_enable]', array(
	'default'			=> 	$options['popular_destination_auto_slide_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[popular_destination_auto_slide_enable]', array(
	'label'             => esc_html__( 'Auto Slide Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );


// popular destination title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_title]', array(
	'default'			=> $options['popular_destination_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[popular_destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_popular_destination_section',
	'active_callback' 	=> 'swingpress_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[popular_destination_title]', array(
		'selector'            => '#interest .section-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[popular_destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_popular_destination_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_sub_title]', array(
	'default'			=> $options['popular_destination_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[popular_destination_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_popular_destination_section',
	'active_callback' 	=> 'swingpress_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[popular_destination_sub_title]', array(
		'selector'            => '#interest .section-header p',
		'settings'            => 'swingpress_pro_theme_options[popular_destination_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_popular_destination_sub_title_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_count]', array(
	'default'          	=> $options['popular_destination_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_popular_destination_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[popular_destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'active_callback'   => 'swingpress_pro_is_popular_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular Destination content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_content_type]', array(
	'default'          	=> $options['popular_destination_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[popular_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_popular_destination_section_enable',
	'choices'			=> swingpress_pro_popular_destination_content_type(),
) );

for ( $i=1; $i <= $options['popular_destination_count']; $i++ ) { 
	// popular_destination pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_popular_destination_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_page_enable',
	) ) );

	// popular_destination posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_popular_destination_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_post_enable',
	) ) );

	// popular_destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_popular_destination_section',
		'choices'			=> swingpress_pro_trip_choices(),
		'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[popular_destination_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[popular_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[popular_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[popular_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[popular_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[popular_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[popular_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[popular_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_popular_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_popular_destination_section_content_destination_enable'
) ) );

