<?php
/**
 * popular_product Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add popular_product section
$wp_customize->add_section( 'swingpress_pro_recent_product_section', array(
    'title'             => esc_html__( 'Recent Product Section','swingpress-pro' ),
    'description'       => esc_html__( 'Recent Product Section Section options.', 'swingpress-pro' ),
    'panel'             => 'swingpress_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_second_layout( $control )
        );
    },
) );

// popular_product content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_section_enable]', array(
    'default'           =>  $options['recent_product_section_enable'],
    'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[recent_product_section_enable]', array(
    'label'             => esc_html__( 'Recent product Section Enable', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'on_off_label'      => swingpress_pro_switch_options(),
) ) );


// popular_product title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['recent_product_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_product_title]', array(
    'label'             => esc_html__( 'Title', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'active_callback'   => 'swingpress_pro_is_recent_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[recent_product_title]', array(
        'selector'            => '#recent-products .section-header h2',
        'settings'            => 'swingpress_pro_theme_options[recent_product_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'swingpress_pro_recent_product_title_partial',
    ) );
}


// popular_product title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_sub_title]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['recent_product_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_product_sub_title]', array(
    'label'             => esc_html__( 'Recent Product Description', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'active_callback'   => 'swingpress_pro_is_recent_product_section_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[recent_product_sub_title]', array(
        'selector'            => '#recent-products .section-header p',
        'settings'            => 'swingpress_pro_theme_options[recent_product_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'swingpress_pro_recent_product_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_count]', array(
    'default'           => $options['recent_product_count'],
    'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
    'validate_callback' => 'swingpress_pro_validate_recent_product_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_product_count]', array(
    'label'             => esc_html__( 'Number of Product', 'swingpress-pro' ),
    'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'active_callback'   => 'swingpress_pro_is_recent_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 4,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_content_type]', array(
    'default'           => $options['recent_product_content_type'],
    'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_product_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'type'              => 'select',
    'active_callback'   => 'swingpress_pro_is_recent_product_section_enable',
    'choices'           => swingpress_pro_latest_product_content_type(),
) );

for( $i = 1 ; $i <= $options['recent_product_count'] ; $i++ ){

    $wp_customize->add_setting( 'swingpress_pro_theme_options[recent_product_content_product_' . $i . ']', array(
        'sanitize_callback' => 'swingpress_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[recent_product_content_product_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'swingpress-pro' ), $i ),
        'section'           => 'swingpress_pro_recent_product_section',
        'choices'           => swingpress_pro_product_choices(),
        'active_callback'   => 'swingpress_pro_is_recent_product_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'swingpress_pro_theme_options[recent_product_content_product_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[recent_product_content_product_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'swingpress-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'swingpress-pro' ),
    'section'           => 'swingpress_pro_recent_product_section',
    'taxonomy'          => class_exists('WooCommerce') ? 'product_cat' : 'category',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'swingpress_pro_is_recent_product_section_content_product_category_enable',
) ) );
