<?php
/**
 * recent Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add recent section
$wp_customize->add_section( 'swingpress_pro_recent_section', array(
	'title'             => esc_html__( 'Recent Posts','swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_third_layout( $control )
        );
    },
) );

// recent content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_section_enable]', array(
	'default'			=> 	$options['recent_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[recent_section_enable]', array(
	'label'             => esc_html__( 'Recent Posts Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_recent_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// recent title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_recent_section',
	'active_callback' 	=> 'swingpress_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[recent_title]', array(
		'selector'            => '#recent-posts-section .section-header h2',
		'settings'            => 'swingpress_pro_theme_options[recent_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_recent_title_partial',
		) );
}

// recent title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_sub_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_recent_section',
	'active_callback' 	=> 'swingpress_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[recent_sub_title]', array(
		'selector'            => '#recent-posts-section .section-header p',
		'settings'            => 'swingpress_pro_theme_options[recent_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_recent_sub_title_partial',
		) );
}


$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_btn_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_recent_section',
	'active_callback' 	=> 'swingpress_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[recent_btn_title]', array(
		'selector'            => '#recent-posts-section .read-more a',
		'settings'            => 'swingpress_pro_theme_options[recent_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_recent_btn_title_partial',
		) );
}




// recent content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_content_type]', array(
	'default'          	=> $options['recent_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_recent_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_recent_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'swingpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'swingpress-pro' ),
		'category' 	=> esc_html__( 'Category', 'swingpress-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'swingpress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_count]', array(
	'default'          	=> $options['recent_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_recent_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[recent_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_recent_section',
	'active_callback'   => 'swingpress_pro_is_recent_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['recent_count']; $i++ ) :
	// recent pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[recent_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_recent_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_recent_section_content_page_enable',
	) ) );

	// recent posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[recent_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_recent_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_recent_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[recent_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[recent_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_recent_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_recent_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'swingpress_pro_theme_options[recent_category_exclude]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Category_Control( $wp_customize,'swingpress_pro_theme_options[recent_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_recent_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'swingpress_pro_is_recent_section_content_recent_enable'
) ) );

