<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'swingpress_pro_service_section', array(
	'title'             => esc_html__( 'Services','swingpress-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
        );
    },
) );

// Service content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );


// service title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_service_section',
	'active_callback' 	=> 'swingpress_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[service_title]', array(
		'selector'            => '#service-section .section-header h2',
		'settings'            => 'swingpress_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_service_title_partial',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[service_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[service_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_service_section',
	'active_callback' 	=> 'swingpress_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[service_sub_title]', array(
		'selector'            => '#service-section .section-header p',
		'settings'            => 'swingpress_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_service_sub_title_partial',
    ) );
}


$wp_customize->add_setting( 'swingpress_pro_theme_options[service_section_icon_enable]', array(
	'default'			=> 	$options['service_section_icon_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[service_section_icon_enable]', array(
	'label'             => esc_html__( 'Service Section Icon Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'active_callback'   => 'swingpress_pro_is_service_section_enable',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// Servuce count number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_service_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'active_callback'   => 'swingpress_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_service_section_enable',
	'choices'			=> swingpress_pro_service_content_type(),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Icon_Picker( $wp_customize, 'swingpress_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_service_section',
		'active_callback'	=> 'swingpress_pro_is_service_section_icon_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_service_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_service_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_service_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'swingpress_pro_theme_options[service_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[service_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_service_section',
		'choices'			=> swingpress_pro_trip_choices(),
		'active_callback'	=> 'swingpress_pro_is_service_section_content_trip_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Swingpress_Pro_Customize_Horizontal_Line( $wp_customize, 'swingpress_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'swingpress_pro_service_section',
			'active_callback' => 'swingpress_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_service_section_content_category_enable'
) ) );

$wp_customize->add_setting(  'swingpress_pro_theme_options[service_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[service_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_service_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[service_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[service_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_service_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[service_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[service_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_service_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_service_section_content_destination_enable'
) ) );