<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'swingpress_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','swingpress-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
            ||
            swingpress_pro_is_second_layout( $control )
            ||
            swingpress_pro_is_third_layout( $control )
        );
    },
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
	'active_callback' 	=> 'swingpress_pro_is_slider_section_enable',
) ) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_design]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
	'default'			=> $options['slider_design'],
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[slider_design]', array(
	'label'           	=> esc_html__( 'Slider Design', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_slider_section',
	'active_callback' 	=> 'swingpress_pro_is_slider_section_enable',
	'type'				=> 'select',
	'choices'				=> array(
		'first-design'		=> 'first-design',
		'second-design'		=> 'second-design'
	),
) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_content_color]', array(
	'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'swingpress_pro_theme_options[slider_content_color]', array(
	'label'           	=> esc_html__( 'Slider Contet Color', 'swingpress-pro' ),
	'section'  => 'swingpress_pro_slider_section',
) ) );


// Slider btn label setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_slider_section',
	'active_callback' 	=> 'swingpress_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#featured-slider-section .read-more a',
		'settings'            => 'swingpress_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_slider_btn_label_partial',
    ) );
}
// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_slider_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'active_callback'   => 'swingpress_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_slider_section_enable',
	'choices'			=> swingpress_pro_main_slider_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_label_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[slider_label_'.$i.']', array(
		'label'           	=> esc_html__( 'Slider Label ', 'swingpress-pro' ).$i,
		'section'        	=> 'swingpress_pro_slider_section',
		'active_callback' 	=> 'swingpress_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_slider_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_slider_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_slider_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'swingpress_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_slider_section',
		'choices'			=> swingpress_pro_trip_choices(),
		'active_callback'	=> 'swingpress_pro_is_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_slider_section_content_category_enable'
) ) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[slider_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[slider_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_slider_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[slider_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[slider_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_slider_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[slider_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[slider_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_slider_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_slider_section_content_destination_enable'
) ) );
