<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'swingpress_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','swingpress-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
            ||
            swingpress_pro_is_second_layout( $control )
            ||
            swingpress_pro_is_third_layout( $control )
        );
    },
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_subscription_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// subscription description setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_subscription_section',
	'active_callback' 	=> 'swingpress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now .section-header p.section-subtitle',
		'settings'            => 'swingpress_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_subscription_section',
	'active_callback' 	=> 'swingpress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'swingpress_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'swingpress_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'swingpress_pro_subscription_title_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'swingpress_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'swingpress-pro' ),
	'section'        	=> 'swingpress_pro_subscription_section',
	'active_callback' 	=> 'swingpress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );