<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'swingpress_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','swingpress-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'swingpress-pro' ),
	'panel'             => 'swingpress_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            swingpress_pro_is_default_layout( $control )
            ||
            swingpress_pro_is_second_layout( $control )
        );
    },
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_testimonial_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
) ) );

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'swingpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Swingpress_Pro_Switch_Control( $wp_customize, 'swingpress_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_testimonial_section',
	'on_off_label' 		=> swingpress_pro_switch_options(),
	'active_callback' 	=> 'swingpress_pro_is_testimonial_section_enable',
) ) );

$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_image]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'swingpress_pro_theme_options[testimonial_image]',
		array(
		'label'       		=> esc_html__( 'Testimonial Image', 'swingpress-pro' ),
		'section'     		=> 'swingpress_pro_testimonial_section',
		'active_callback' 	=> 'swingpress_pro_is_testimonial_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'swingpress_pro_sanitize_number_range',
	'validate_callback' => 'swingpress_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'swingpress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 99. Please input the valid number and save. Then refresh the page to see the change.', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_testimonial_section',
	'active_callback'   => 'swingpress_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 99,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'swingpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'swingpress_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'swingpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'swingpress-pro' ),
		'category' 	=> esc_html__( 'Category', 'swingpress-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'swingpress-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'swingpress_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'swingpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Swingpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'swingpress_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'swingpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'swingpress-pro' ),
	'section'           => 'swingpress_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'swingpress_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_testimonial_section',
		'choices'			=> swingpress_pro_page_choices(),
		'active_callback'	=> 'swingpress_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Swingpress_Pro_Dropdown_Chooser( $wp_customize, 'swingpress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'swingpress-pro' ), $i ),
		'section'           => 'swingpress_pro_testimonial_section',
		'choices'			=> swingpress_pro_post_choices(),
		'active_callback'	=> 'swingpress_pro_is_testimonial_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'swingpress-pro' ), $i ),
		'section'        	=> 'swingpress_pro_testimonial_section',
		'active_callback' 	=> 'swingpress_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );


	// testimonial title setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'swingpress-pro' ), $i ),
		'section'        	=> 'swingpress_pro_testimonial_section',
		'active_callback' 	=> 'swingpress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'swingpress-pro' ), $i ),
		'section'        	=> 'swingpress_pro_testimonial_section',
		'active_callback' 	=> 'swingpress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'swingpress_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'swingpress_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'swingpress-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'swingpress-pro' ), 700, 600 ),
			'section'     		=> 'swingpress_pro_testimonial_section',
			'active_callback'	=> 'swingpress_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'swingpress_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'swingpress-pro' ), $i ),
		'section'        	=> 'swingpress_pro_testimonial_section',
		'active_callback' 	=> 'swingpress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'swingpress_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Swingpress_Pro_Customize_Horizontal_Line( $wp_customize, 'swingpress_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'swingpress_pro_testimonial_section',
			'active_callback' => 'swingpress_pro_is_testimonial_section_content_author_enable',
			'type'			  => 'hr'
	) ) );
endfor;

