<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function swingpress_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'swingpress-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function swingpress_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'swingpress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function swingpress_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'swingpress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function swingpress_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'swingpress-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'swingpress_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function swingpress_pro_typography_options(){
        $choices = array(
            ''   => esc_html__( 'Default', 'swingpress-pro' ),
            'Rajdhani'   => esc_html__( 'Rajdhani', 'swingpress-pro' ),
            'Cherry Swash'   => esc_html__( 'Cherry Swash', 'swingpress-pro' ),
            'Philosopher'   => esc_html__( 'Philosopher', 'swingpress-pro' ),
            'Slabo 27px'   => esc_html__( 'Slabo 27px', 'swingpress-pro' ),
            'Dosis'   => esc_html__( 'Dosis', 'swingpress-pro' ),
            'News Cycle'     => esc_html__( 'News Cycle', 'swingpress-pro' ),
            'Pontano Sans'     => esc_html__( 'Pontano Sans', 'swingpress-pro' ),
            'Gudea'     => esc_html__( 'Gudea', 'swingpress-pro' ),
            'Quattrocento'     => esc_html__( 'Quattrocento', 'swingpress-pro' ),
            'Khand'     => esc_html__( 'Khand', 'swingpress-pro' ),
        );

        $output = apply_filters( 'swingpress_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'swingpress_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function swingpress_pro_selected_sidebar() {
        $swingpress_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'swingpress-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'swingpress-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'swingpress-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'swingpress-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'swingpress-pro' ),
        );

        $output = apply_filters( 'swingpress_pro_selected_sidebar', $swingpress_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function swingpress_pro_site_layout() {
        $swingpress_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'swingpress_pro_site_layout', $swingpress_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'swingpress_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function swingpress_pro_global_sidebar_position() {
        $swingpress_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'swingpress_pro_global_sidebar_position', $swingpress_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'swingpress_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function swingpress_pro_sidebar_position() {
        $swingpress_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'swingpress_pro_sidebar_position', $swingpress_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'swingpress_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function swingpress_pro_pagination_options() {
        $swingpress_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'swingpress-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'swingpress-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'swingpress-pro' ),
        );

        $output = apply_filters( 'swingpress_pro_pagination_options', $swingpress_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function swingpress_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'swingpress-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'swingpress-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'swingpress-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'swingpress-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'swingpress-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'swingpress-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'swingpress-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'swingpress-pro' ),
        );
        return apply_filters( 'swingpress_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'swingpress_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function swingpress_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'swingpress-pro' ),
            'off'       => esc_html__( 'Disable', 'swingpress-pro' )
        );
        return apply_filters( 'swingpress_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'swingpress_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function swingpress_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'swingpress-pro' ),
            'off'       => esc_html__( 'No', 'swingpress-pro' )
        );
        return apply_filters( 'swingpress_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'swingpress_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function swingpress_pro_sortable_sections() {
        $sections = array(
            'slider'                    => esc_html__( 'Main Slider', 'swingpress-pro' ),
            'trip_search'               => esc_html__( 'Trip Search', 'swingpress-pro' ),
            'service'                   => esc_html__( 'Services', 'swingpress-pro' ),
            'featured'                  => esc_html__( 'Featured', 'swingpress-pro' ),
            'about'                     => esc_html__( 'About Us', 'swingpress-pro' ),
            'package'                   => esc_html__( 'Package', 'swingpress-pro' ),
            'popular_destination'       => esc_html__( 'Popular Destination', 'swingpress-pro' ),
            'testimonial'               => esc_html__( 'Testimonial', 'swingpress-pro' ),
            'blog'                      => esc_html__( 'Blog', 'swingpress-pro' ),
            'gallery'                   => esc_html__( 'Gallery', 'swingpress-pro' ),
            'subscription'              => esc_html__( 'Subscription', 'swingpress-pro' ),
            'featured_post'             => esc_html__( 'Featured Post', 'swingpress-pro' ),
            'inner_wrapper'             => esc_html__( 'Inner Wrapper', 'swingpress-pro' ),
            'recent'                    => esc_html__( 'Recent', 'swingpress-pro' ),
            'featured_product'          => esc_html__( 'Featured Product', 'swingpress-pro' ),
            'recent_product'            => esc_html__( 'Recent Product', 'swingpress-pro' ),
            'latest_product'            => esc_html__( 'Latest Product', 'swingpress-pro' ),
            'latest_post'               => esc_html__( 'Latest Post', 'swingpress-pro' ),
            'breaking_news'             => esc_html__( 'Breaking News', 'swingpress-pro' ),
            'magazine_featured_post'    => esc_html__( 'Magazine Featured Post', 'swingpress-pro' ),
            'magazine_latest_post'      => esc_html__( 'Magazine Latest Post', 'swingpress-pro' ),
            'magazine_most_viewed_post' => esc_html__( 'Magazine Most Viewed Post', 'swingpress-pro' ),
            'magazine_wrapper'          => esc_html__( 'Magazine Wrapper', 'swingpress-pro' ),
        );
        return apply_filters( 'swingpress_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'swingpress_pro_main_slider_content_type' ) ) :
    /**
     * main slider Options
     * @return array site main slider options
     */
    function swingpress_pro_main_slider_content_type() {
        $swingpress_pro_main_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_main_slider_content_type = array_merge( $swingpress_pro_main_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_main_slider_content_type', $swingpress_pro_main_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_service_content_type' ) ) :
    /**
     * service options
     * @return array site service options
     */
    function swingpress_pro_service_content_type() {
        $swingpress_pro_service_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_service_content_type = array_merge( $swingpress_pro_service_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_service_content_type', $swingpress_pro_service_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_blog_content_type' ) ) :
    /**
     * blog options
     * @return array site blog options
     */
    function swingpress_pro_blog_content_type() {
        $swingpress_pro_blog_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
            'recent'    => esc_html__( 'Recent', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_blog_content_type = array_merge( $swingpress_pro_blog_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_blog_content_type', $swingpress_pro_blog_content_type );


        return $output;
    }
endif;



if ( ! function_exists( 'swingpress_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function swingpress_pro_featured_content_type() {
        $swingpress_pro_featured_content_type = array(
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_featured_content_type = array_merge( $swingpress_pro_featured_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

         if ( class_exists( 'WooCommerce' ) ) {

            $swingpress_pro_featured_content_type = array_merge( $swingpress_pro_featured_content_type, array(
                'product_cat'       => esc_html__( 'Product Category', 'swingpress-pro' ),
                ) );
    
        }

        $output = apply_filters( 'swingpress_pro_featured_content_type', $swingpress_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function swingpress_pro_popular_destination_content_type() {
        $swingpress_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_popular_destination_content_type = array_merge( $swingpress_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_popular_destination_content_type', $swingpress_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_package_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function swingpress_pro_package_content_type() {
        $swingpress_pro_package_content_type = array(
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_package_content_type = array_merge( $swingpress_pro_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_package_content_type', $swingpress_pro_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_traveler_choice_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function swingpress_pro_traveler_choice_content_type() {
        $swingpress_pro_traveler_choice_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_traveler_choice_content_type = array_merge( $swingpress_pro_traveler_choice_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_traveler_choice_content_type', $swingpress_pro_traveler_choice_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_discover_places_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function swingpress_pro_discover_places_content_type() {
        $swingpress_pro_discover_places_content_type = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $swingpress_pro_discover_places_content_type = array_merge( $swingpress_pro_discover_places_content_type, array(
                'trip'          => esc_html__( 'Trip', 'swingpress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'swingpress-pro' ),
                'destination'   => esc_html__( 'Destination', 'swingpress-pro' ),
                'activity'      => esc_html__( 'Activity', 'swingpress-pro' ),
                ) );
        }

        $output = apply_filters( 'swingpress_pro_discover_places_content_type', $swingpress_pro_discover_places_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'swingpress_pro_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function swingpress_pro_heading_tags() {
        
        $swingpress_pro_heading_tags = array(
			'h1'	=> esc_html__('H1', 'swingpress-pro'),
			'h2'	=> esc_html__('H2', 'swingpress-pro'),
			'h3'	=> esc_html__('H3', 'swingpress-pro'),
			'h4'	=> esc_html__('H4', 'swingpress-pro'),
			'h5'	=> esc_html__('H5', 'swingpress-pro'),
			'h6'	=> esc_html__('H6', 'swingpress-pro'),
			'p'		=> esc_html__('Paragraph', 'swingpress-pro'),
		);

        $output = apply_filters( 'swingpress_pro_heading_tags', $swingpress_pro_heading_tags );


        return $output;
    }
endif;


if ( ! function_exists( 'swingpress_pro_popular_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function swingpress_pro_popular_product_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'swingpress-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'swingpress-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'swingpress-pro' ),
            );
        }

        return apply_filters( 'swingpress_pro_popular_product_content_type', $arr );
    }
endif;

if ( ! function_exists( 'swingpress_pro_latest_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function swingpress_pro_latest_product_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'swingpress-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'swingpress-pro' ),
            );
        }

        return apply_filters( 'swingpress_pro_latest_product_content_type', $arr );
    }
endif;

if ( ! function_exists( 'swingpress_pro_featured_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function swingpress_pro_product_content_type() {
        $arr = array(
            'page'      => esc_html__( 'Page', 'swingpress-pro' ),
            'post'      => esc_html__( 'Post', 'swingpress-pro' ),
            'category'  => esc_html__( 'Category', 'swingpress-pro' ),
        );
    
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, array(
                'product'           => esc_html__( 'Product', 'swingpress-pro' ),
                'product-cat'           => esc_html__( 'Product', 'swingpress-pro' ),
                ) );
        }

        return apply_filters( 'swingpress_pro_featured_product_content_type', $arr );
    }
endif;