<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */
if ( ! function_exists( 'swingpress_pro_add_featured_product_section' ) ) :
    /**
    * Add featured section
    *
    *@since Swingpress Pro 1.0.0
    */
    function swingpress_pro_add_featured_product_section() {
    	$options = swingpress_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $featured_product_enable = apply_filters( 'swingpress_pro_section_status', true, 'featured_product_section_enable' );

        if ( true !== $featured_product_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'swingpress_pro_filter_featured_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        
        // Render destination section now.
        swingpress_pro_render_featured_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'swingpress_pro_get_featured_product_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Swingpress Pro 1.0.0
    * @param array $input featured section details.
    */
    function swingpress_pro_get_featured_product_section_details( $input ) {
        $options = swingpress_pro_get_theme_options();

        // Content type.
        $featured_product_content_type  = $options['featured_product_content_type'];
        $featured_product_count = ! empty( $options['featured_product_count'] ) ? $options['featured_product_count'] : 3;
        
        $content = array();
        switch ( $featured_product_content_type ) {
        	
            case 'category':
                for ( $i = 1; $i <= $featured_product_count; $i++ ) {

                    if ( ! empty( $options['featured_product_content_category_' . $i] ) ){
                        $page_post['id']      = $options['featured_product_content_category_' . $i];
                        $terms = get_term_by( 'id',  $page_post['id'], 'category' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_category_link( $page_post['id'] );
                            $page_post['count']   = $terms->count;
                            $page_post['image'] = ! empty( $options['featured_product_background_image_' . $i] ) ? $options['featured_product_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                        endif;
                    }
                    if ( ! empty(  $options['featured_product_content_category_' . $i] ) )
                        array_push( $content, $page_post );
                }                     
            break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_trip_types_' . $i] ) ){
                        $page_post['id']      = $options['featured_product_content_trip_types_' . $i];
                        $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                        
                        $terms = get_term_by( 'id',  $page_post['id'], 'itinerary_types' );
                        
                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'itinerary_types' );
                            $page_post['count']   = $terms->count;
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                        endif;
                    }
                    if ( ! empty(  $options['featured_product_content_trip_types_' . $i] ) )
                        array_push( $content, $page_post );
                }
                     
            break;

            case 'destination': //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                    
                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_destination_' . $i] ) ){
                        $page_post['id']      = $options['featured_product_content_destination_' . $i];

                        $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                        $terms = get_term_by( 'id',  $page_post['id'], 'travel_locations' );
                        
                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'travel_locations' );
                            $page_post['count']   = $terms->count;
                        endif;
                    }

                    if ( ! empty(  $options['featured_product_content_destination_' . $i] ) )
                        array_push( $content, $page_post );
                }   

            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_activity_' . $i] ) ){
                        $page_post['id']      = $options['featured_product_content_activity_' . $i];


                        $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                        $terms = get_term_by( 'id',  $page_post['id'], 'activity' );
                            
                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'activity' );
                            $page_post['count']   = $terms->count;
                        endif;
                    }

                    if ( ! empty(  $options['featured_product_content_activity_' . $i] ) )
                        array_push( $content, $page_post );
                }  
                   
            break;

            case 'product_cat':
  
                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_product_category_' . $i] ) ){
                        $page_post['id']      = $options['featured_product_content_product_category_' . $i];
                        $thumbnail_id = get_term_meta( $options['featured_product_content_product_category_'.$i], 'thumbnail_id', true );
                        $cat_image = !empty( wp_get_attachment_url( $thumbnail_id ) ) ? wp_get_attachment_url( $thumbnail_id ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';
                        $terms = get_term_by( 'id',  $page_post['id'], 'product_cat' );
                            
                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['image'] =  $cat_image;
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'product_cat' );
                            $page_post['count']   = $terms->count;
                        endif;
                    }

                    if ( ! empty(  $options['featured_product_content_product_category_' . $i] ) )
                        array_push( $content, $page_post );
                }  
                   
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'swingpress_pro_filter_featured_product_section_details', 'swingpress_pro_get_featured_product_section_details' );


if ( ! function_exists( 'swingpress_pro_render_featured_product_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Swingpress Pro 1.0.0
   *
   */
   function swingpress_pro_render_featured_product_section( $content_details = array() ) {
        $options = swingpress_pro_get_theme_options();
        $featured_product_content_type  = $options['featured_product_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="swingpress_pro_featured_product_section" class="relative page-section same-background">
            <div id="featured-products">
                <div class="wrapper">
                    <div class="col-2 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header><!-- .entry-header -->
                                    </div><!-- .entry-container -->  
                                </div>                                                    
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .grid --> 
                </div><!-- .wrapper -->
            </div><!-- #latest-products -->
        </div>
        
    <?php }
endif;