<?php
/**
 * gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */
if ( ! function_exists( 'swingpress_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Swingpress Pro 1.0.0
    */
    function swingpress_pro_add_gallery_section() {
    	$options = swingpress_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'swingpress_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'swingpress_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        swingpress_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'swingpress_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Swingpress Pro 1.0.0
    * @param array $input gallery section details.
    */
    function swingpress_pro_get_gallery_section_details( $input ) {
        $options = swingpress_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_count = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 4;
        
        $content = array();
        switch ( $gallery_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['gallery_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = swingpress_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'swingpress_pro_filter_gallery_section_details', 'swingpress_pro_get_gallery_section_details' );


if ( ! function_exists( 'swingpress_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Swingpress Pro 1.0.0
   *
   */
   function swingpress_pro_render_gallery_section( $content_details = array() ) {
        $options = swingpress_pro_get_theme_options();
        $gallery_content_type  = $options['gallery_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="swingpress_pro_gallery_section" class="relative page-section same-background">
            <div id="gallery" >
                <div class="section-header-wrapper wrapper clear">
                    <div class="section-header clear">
                      <?php if ( !empty( $options['gallery_title'] ) ): ?>
                          <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                      <?php endif ?>
                      <?php if ( !empty( $options['gallery_btn_title'] ) && !empty( $options['gallery_btn_url'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $options['gallery_btn_url'] ); ?>" class="btn">
                              <?php echo esc_html( $options['gallery_btn_title'] ); ?>
                            </a>
                        </div>
                      <?php endif ?>                        
                    </div><!-- .section-header -->
                    <?php if ( !empty( $options['gallery_short_description'] ) ): ?>
                      <div class="section-content clear">
                        <p><?php echo esc_html( $options['gallery_short_description'] ); ?></p>
                      </div><!-- .section-content -->
                    <?php endif ?>                    
                </div><!-- .section-header-wrapper -->

                <div class="grid">
                  <?php foreach ( $content_details as $content ): ?>
                     <article class="grid-item">
                          <div class="hover-item">
                              <a href="<?php echo esc_url( $content['url'] ); ?>">
                                  <img src="<?php echo esc_url( $content['image'] ); ?>">
                              </a>    
                         </div>
                     </article>
                  <?php endforeach ?>
                </div><!-- .grid -->

                <?php if ( !empty( $options['gallery_btn_title'] ) && !empty( $options['gallery_btn_url'] ) ): ?>
                  <div class="read-more">
                      <a href="<?php echo esc_url( $options['gallery_btn_url'] ); ?>" class="btn">
                        <?php echo esc_html( $options['gallery_btn_title'] ); ?>
                      </a>
                  </div>
                <?php endif ?>   
            </div><!-- #gallery -->
        </div>            
    <?php }
endif;