<?php
/**
 * popular_product section
 *
 * This is the template for the content of popular_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'swingpress_pro_add_latest_product_section' ) ) :
    /**
    * Add popular_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function swingpress_pro_add_latest_product_section() {
        $options = swingpress_pro_get_theme_options();
        // Check if popular_product is enabled on frontpage
        $latest_product_enable = apply_filters( 'swingpress_pro_section_status', true, 'latest_product_section_enable' );

        if ( true !== $latest_product_enable ) {
            return false;
        }
        // Get popular_product section details
        $section_details = array();
        $section_details = apply_filters( 'swingpress_pro_filter_latest_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render popular_product section now.
        swingpress_pro_render_latest_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'swingpress_pro_get_latest_product_section_details' ) ) :
    /**
    * popular_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input popular_product section details.
    */
    function swingpress_pro_get_latest_product_section_details( $input ) {
        $options = swingpress_pro_get_theme_options();

        // Content type.
        $latest_product_content_type  = $options['latest_product_content_type'];     
        $latest_product_count = ! empty( $options['latest_product_count'] ) ? $options['latest_product_count'] : 4; 
        
        $content = array();
        $content = array();
        switch ( $latest_product_content_type ) {

            case 'product':
                $product_ids = array();

                for ( $i = 1; $i <= $latest_product_count; $i++ ) {
                    if ( ! empty( $options['latest_product_content_product_' . $i] ) )
                        $product_ids[] = $options['latest_product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $product_ids,
                    'posts_per_page'    => $latest_product_count,
                    'orderby'           => 'post__in',
                    );
            break;

            case 'product_cat':
                $cat_id = ! empty( $options['latest_product_content_product_category'] ) ? $options['latest_product_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $latest_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = swingpress_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_product section content details.
add_filter( 'swingpress_pro_filter_latest_product_section_details', 'swingpress_pro_get_latest_product_section_details' );


if ( ! function_exists( 'swingpress_pro_render_latest_product_section' ) ) :
  /**
   * Start popular_product section
   *
   * @return string popular_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function swingpress_pro_render_latest_product_section( $content_details = array() ) {
        $options = swingpress_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="swingpress_pro_latest_product_section" class="relative page-section">
            <div id="latest-products" >
                <div class="wrapper">
                    <div class="section-header">
                        <?php if ( ! empty( $options['latest_product_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['latest_product_title'] ); ?></h2>
                        <?php endif; ?>
                        <?php if ( ! empty( $options['latest_product_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['latest_product_sub_title'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <ul class="products col-4">
                        <?php foreach ( $content_details as $content ): 
                            $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                            ?>
                            <li class="product featured-products">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                    <img src="<?php echo esc_url($image); ?>">
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    <span class="price">
                                        <?php 
                                        $product = new WC_Product( $content['id'] );
                                        echo $product->get_price_html();
                                        ?>
                                    </span>
                                </a>
                            </li>
                        <?php endforeach; ?>

                        </ul><!-- .product-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #recent-products --> 
        </div>
        
    <?php }
endif;