<?php
/**
 * Package section
 *
 * This is the template for the content of package section
 *
 * @package Theme Palace
 * @subpackage Swingpress Pro
 * @since Swingpress Pro 1.0.0
 */
if ( ! function_exists( 'swingpress_pro_add_package_section' ) ) :
    /**
    * Add package section
    *
    *@since Swingpress Pro 1.0.0
    */
    function swingpress_pro_add_package_section() {
    	$options = swingpress_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $package_enable = apply_filters( 'swingpress_pro_section_status', true, 'package_section_enable' );

        if ( true !== $package_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'swingpress_pro_filter_package_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        swingpress_pro_render_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'swingpress_pro_get_package_section_details' ) ) :
    /**
    * package section details.
    *
    * @since Swingpress Pro 1.0.0
    * @param array $input package section details.
    */
    function swingpress_pro_get_package_section_details( $input ) {
        $options = swingpress_pro_get_theme_options();

        // Content type.
        $package_content_type  = $options['package_content_type'];
        
        $content = array();
        $args = array();
        $content['cats'] = array();
        switch ( $package_content_type ) {
        	
            case 'category':
                $cat_ids = ! empty( $options['package_content_category'] ) ? $options['package_content_category'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => 4,
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;               
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['package_content_trip_types'] ) ? $options['package_content_trip_types'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'itinerary_types',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                
                $content['taxonomy'] = 'itinerary_types';
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['package_content_destination'] ) ? $options['package_content_destination'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'travel_locations',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'travel_locations';
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['package_content_activity'] ) ? $options['package_content_activity'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'activity',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'activity';
            break;

            default:
            break;
        }

        $i = 0;
        foreach ( $args as $arg ) :
            $content['details'][$i] = array();
            // Run The Loop.
            $query = new WP_Query( $arg );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['id']        = get_the_id();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post[$i]['image']  	 = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'][$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'swingpress_pro_filter_package_section_details', 'swingpress_pro_get_package_section_details' );


if ( ! function_exists( 'swingpress_pro_render_package_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Swingpress Pro 1.0.0
   *
   */
   function swingpress_pro_render_package_section( $content_details = array() ) {
        $options = swingpress_pro_get_theme_options();
        $package_content_type  = $options['package_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="swingpress_pro_package_section" class="relative page-section col-4">
                <div class="wrapper">
                    <div class="section-header clear">
                        <?php if ( ! empty( $options['package_title'] ) ) : ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $options['package_title'] ); ?></h2>
                                <p class="section-subtitle">More than 2000+ travel destinations</p>
                            </div><!-- .section-header -->
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content clear">
                        <ul class="tabs">
                            <?php $i = 1; foreach ( $content_details['cats'] as $content ) :
                                if ( 'category' == $package_content_type ) : ?>
                                    <li data-tab="<?php echo 'package-' . absint( $content ); ?>" class="<?php echo ( $i == 1 ) ? 'active' : ''; ?>"><a href="#"><?php echo esc_html( get_cat_name( $content ) ); ?></a></li>
                                <?php else : 
                                    $cat = get_term_by( 'id', $content, $content_details['taxonomy'] );  ?>
                                    <li data-tab="<?php echo 'package-' . absint( $content ); ?>" class="<?php echo ( $i == 1 ) ? 'active' : ''; ?>"><a href="#"><?php echo esc_html( $cat->name ); ?></a></li>
                                <?php endif;
                            $i++; endforeach; ?>
                        </ul>
                         <?php $i = 0; foreach ( $content_details['details'] as $content_detail ) : ?>
                            <div id="<?php echo 'package-' . absint( $content_details['cats'][$i] ); ?>" class="tab-content <?php echo ( $i == 0 ) ? 'active' : ''; ?>">
                               
                                <?php foreach ( $content_detail as $content ) : ?>

                                    <article>
                                        <div class="swingpress_pro_package_section-wrapper">
                                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            </div><!-- .featured-image -->

                                            <div class="entry-container clear">
                                                <div class="entry-header-wrapper clear">
                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                    </header>   
                                                </div><!-- .entry-header-wrapper -->

                                                <?php if ( 'category' !== $package_content_type && class_exists('WP_Travel') ): ?>
                                                    <div class="meta-wrapper clear">
                                                        <?php if( !in_array( $package_content_type, array( 'category', 'page', 'post' ) ) ) : ?>
                                                            <div class="duration">
                                                               <?php wp_travel_get_trip_duration($content['id']); ?>
                                                            </div>
                                                          <?php endif ?>

                                                        <div class="rating">
                                                            <?php
                                                                $average_rating = wp_travel_get_average_rating( $content['id'] ); 
                                                            ?>
                                                            <div class="wp-travel-average-review" title="<?php printf( esc_attr__( 'Rated %s out of 5', 'swingpress-pro' ), $average_rating ); ?>">
                                                                <span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
                                                                    <strong itemprop="ratingValue" class="rating"><?php echo esc_html( $average_rating ); ?></strong> <?php printf( esc_html__( 'out of %1$s5%2$s', 'swingpress-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
                                                                </span>
                                                            </div>
                                                            <span class="trip-price">
                                                                <?php 
                                                                    $trip_price = WP_Travel_Helpers_Pricings::get_price( array('trip_id'=>$content['id']) );
                                                                    echo wp_travel_get_formated_price_currency( $trip_price ); 
                                                                ?>
                                                            </span><!-- .trip-price -->
                                                        </div>
                                                    </div><!-- .meta-wrapper -->
                                                <?php endif ?>
                                                
                                            </div><!-- .entry-container -->
                                        </div>
                                    </article>
                                <?php endforeach; ?>                               
                            </div><!-- #new-york -->
                        <?php $i++; endforeach; ?>
                    </div>
            
                </div><!-- .wrapper -->
            </div>
        
    <?php }
endif;